@@ -23,7 +23,7 @@ use GRID::Machine::MakeAccessors; # Order is important. This must be the first!
 use GRID::Machine::Message;
 use GRID::Machine::Result;
 
-our $VERSION = "0.087";
+our $VERSION = "0.088";
 
 sub read_modules {
 
@@ -650,7 +650,7 @@ sub put {
 
   # Check if @files exist in the local system
   # Check if they exist in the remote system. If so what permits they have?
-  system("$scp @files $host:$dest") and die "put Error: copying files @files to $host:$dest\n";
+  system("$scp @files $host:$dest") and die "GRID::Machine::put Error: Copying files @files to $host:$dest\n";
   return 1;
 }
 
@@ -784,5 +784,13 @@ sub qc {
 EOI
 }
 
+sub qx {
+  my $self = shift;
+
+  my $wantarray = wantarray();
+  my $r = $self->qqx($wantarray, $/, @_);
+  $wantarray? $r->Results : $r->result;
+}
+
 1;
 
